# 🌐 Mount Etna

![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-04-Mount-Etna-a/geo-watch-2024-09-04-Mount-Etna-a-2X.gif?raw=true&random=mSepidHfs0Db220P)

- [Wikipedia](https://en.wikipedia.org/wiki/Mount_Etna)
- [Google Map](https://maps.app.goo.gl/vcCRk16tHBPxB3a47): `lat: 37°45'03.6"N`, `lon: 14°59'36.2"E`.

details: [targets.yaml](../targets.yaml).

used by: [`@geo watch`](../).